@@ -33,6 +33,7 @@ from .cluster_service import (
     CompleteNodePoolUpgradeRequest,
     ConfidentialNodes,
     ConfigConnectorConfig,
+    CostManagementConfig,
     CreateClusterRequest,
     CreateNodePoolRequest,
     DailyMaintenanceWindow,
@@ -43,6 +44,8 @@ from .cluster_service import (
     DeleteNodePoolRequest,
     DnsCacheConfig,
     DNSConfig,
+    FastSocket,
+    GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
     GcfsConfig,
     GcpFilestoreCsiDriverConfig,
@@ -54,6 +57,7 @@ from .cluster_service import (
     GetOpenIDConfigResponse,
     GetOperationRequest,
     GetServerConfigRequest,
+    GkeBackupAgentConfig,
     GPUSharingConfig,
     HorizontalPodAutoscaling,
     HttpLoadBalancing,
@@ -61,6 +65,7 @@ from .cluster_service import (
     ILBSubsettingConfig,
     IntraNodeVisibilityConfig,
     IPAllocationPolicy,
+    IPv6AccessType,
     Jwk,
     KubernetesDashboard,
     LegacyAbac,
@@ -113,6 +118,7 @@ from .cluster_service import (
     RecurringTimeWindow,
     ReleaseChannel,
     ReservationAffinity,
+    ResourceLabels,
     ResourceLimit,
     ResourceUsageExportConfig,
     RollbackNodePoolUpgradeRequest,
@@ -134,6 +140,7 @@ from .cluster_service import (
     SetNodePoolSizeRequest,
     ShieldedInstanceConfig,
     ShieldedNodes,
+    StackType,
     StartIPRotationRequest,
     StatusCondition,
     TimeWindow,
@@ -171,6 +178,7 @@ __all__ = (
     "CompleteNodePoolUpgradeRequest",
     "ConfidentialNodes",
     "ConfigConnectorConfig",
+    "CostManagementConfig",
     "CreateClusterRequest",
     "CreateNodePoolRequest",
     "DailyMaintenanceWindow",
@@ -180,6 +188,8 @@ __all__ = (
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
     "DNSConfig",
+    "FastSocket",
+    "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
     "GcfsConfig",
     "GcpFilestoreCsiDriverConfig",
@@ -191,6 +201,7 @@ __all__ = (
     "GetOpenIDConfigResponse",
     "GetOperationRequest",
     "GetServerConfigRequest",
+    "GkeBackupAgentConfig",
     "GPUSharingConfig",
     "HorizontalPodAutoscaling",
     "HttpLoadBalancing",
@@ -248,6 +259,7 @@ __all__ = (
     "RecurringTimeWindow",
     "ReleaseChannel",
     "ReservationAffinity",
+    "ResourceLabels",
     "ResourceLimit",
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
@@ -284,7 +296,9 @@ __all__ = (
     "WorkloadIdentityConfig",
     "WorkloadMetadataConfig",
     "DatapathProvider",
+    "IPv6AccessType",
     "NodePoolUpdateStrategy",
     "PrivateIPv6GoogleAccess",
+    "StackType",
     "UpgradeResourceType",
 )
