@@ -13,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.container import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from .services.cluster_manager import ClusterManagerAsyncClient, ClusterManagerClient
 from .types.cluster_service import (
@@ -48,6 +52,8 @@ from .types.cluster_service import (
     DnsCacheConfig,
     DNSConfig,
     EphemeralStorageConfig,
+    FastSocket,
+    GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
     GcfsConfig,
     GcpFilestoreCsiDriverConfig,
@@ -127,6 +133,7 @@ from .types.cluster_service import (
     RecurringTimeWindow,
     ReleaseChannel,
     ReservationAffinity,
+    ResourceLabels,
     ResourceLimit,
     ResourceUsageExportConfig,
     RollbackNodePoolUpgradeRequest,
@@ -205,7 +212,9 @@ __all__ = (
     "DeleteNodePoolRequest",
     "DnsCacheConfig",
     "EphemeralStorageConfig",
+    "FastSocket",
     "GPUSharingConfig",
+    "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
     "GcfsConfig",
     "GcpFilestoreCsiDriverConfig",
@@ -284,6 +293,7 @@ __all__ = (
     "RecurringTimeWindow",
     "ReleaseChannel",
     "ReservationAffinity",
+    "ResourceLabels",
     "ResourceLimit",
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
