@@ -46,6 +46,8 @@ from .cluster_service import (
     DnsCacheConfig,
     DNSConfig,
     EphemeralStorageConfig,
+    FastSocket,
+    GatewayAPIConfig,
     GcePersistentDiskCsiDriverConfig,
     GcfsConfig,
     GcpFilestoreCsiDriverConfig,
@@ -125,6 +127,7 @@ from .cluster_service import (
     RecurringTimeWindow,
     ReleaseChannel,
     ReservationAffinity,
+    ResourceLabels,
     ResourceLimit,
     ResourceUsageExportConfig,
     RollbackNodePoolUpgradeRequest,
@@ -200,6 +203,8 @@ __all__ = (
     "DnsCacheConfig",
     "DNSConfig",
     "EphemeralStorageConfig",
+    "FastSocket",
+    "GatewayAPIConfig",
     "GcePersistentDiskCsiDriverConfig",
     "GcfsConfig",
     "GcpFilestoreCsiDriverConfig",
@@ -277,6 +282,7 @@ __all__ = (
     "RecurringTimeWindow",
     "ReleaseChannel",
     "ReservationAffinity",
+    "ResourceLabels",
     "ResourceLimit",
     "ResourceUsageExportConfig",
     "RollbackNodePoolUpgradeRequest",
